@@ -21,12 +21,17 @@ parser.add_argument('--version',
     help="Which step of the plugin is this? (1, 2, 3, etc.)",
     required=False,
     type=int)
-parser.add_argument('--server', help='IPv4', type=str)
+parser.add_argument('--server', help='Most of the time an IPv4 or IPv6', type=str)
 parser.add_argument('--database', help='Database name belongs to the server', type=str)
-parser.add_argument('--env', help='Path to .env file', default='.env', type=str)
+parser.add_argument('--env', help='Path to .env file', default=None, type=str)
+parser.add_argument('--username', help='Username for database connection', default=None, type=str)
+parser.add_argument('--password', help='Password for database connection', default=None, type=str)
+parser.add_argument('--db_driver', help="MSSQL driver's location",
+    default="/usr/local/lib/python3.6/dist-packages/pyodbc/drivers/pyodbc.so", type=str)
 
-# load the environment variables from file location
-load_dotenv(dotenv_path=parser.parse_args().env)
+# load the environment variables from file location if exists
+if parser.parse_args().env:
+    load_dotenv(dotenv_path=parser.parse_args().env)
 # DEBUG
 PASS_DATABASE_CONNECTION = True
 
@@ -42,19 +47,21 @@ def special_strftime():
     return x + dic.get(x[-2:], 'th,') + year
 
 if __name__ == "__main__":
-    this_plugin_name = parser.parse_args().plugin
-    query = parser.parse_args().query
+    this_plugin_name = parser.parse_args().plugin or os.environ.get("THIS_PLUGIN_NAME")
+    query = parser.parse_args().query or os.environ.get("QUERY")
     server = parser.parse_args().server or os.environ.get("SERVER")
     database = parser.parse_args().database or os.environ.get("DATABASE")
-    username = os.environ.get("DATABASE_USERNAME")
-    password = os.environ.get("DATABASE_PASSWORD")
-    # /opt/microsoft/msodbcsql17/lib64/libmsodbcsql-17.5.so.1.1
-    driver_location = os.environ.get("DATABASE_DRIVER_PATH")
-    if (server is None
-        or database is None
-        or username is None
-        or password is None):
-        raise Exception("Missing required arguments")
+    username = parser.parse_args().username or os.environ.get("DATABASE_USERNAME")
+    password = parser.parse_args().password or os.environ.get("DATABASE_PASSWORD")
+    driver_location = parser.parse_args().password or os.environ.get("DATABASE_DRIVER_PATH")
+    if server is None:
+        raise Exception("Server is not defined")
+    if database is None:
+        raise Exception("Database is not defined")
+    if username is None:
+        raise Exception("Username is not defined")
+    if password is None:
+        raise Exception("Password is not defined")
     cache = {
         "database":database,
         "query":query,
